pub struct SignatureRequestBuilder { /* private fields */ }Expand description
The SignatureRequestBuilder is used to collect all of the actions in an IdentityUpdate, but without the signatures. It outputs a SignatureRequest, which can then collect the relevant signatures and be turned into an IdentityUpdate.
Implementations
Sourceimpl SignatureRequestBuilder
impl SignatureRequestBuilder
Sourcepub fn new<S: AsRef<str>>(inbox_id: S) -> Self
pub fn new<S: AsRef<str>>(inbox_id: S) -> Self
Create a new IdentityUpdateBuilder for the given inbox_id
Sourcepub fn create_inbox(self, signer_identity: Identifier, nonce: u64) -> Self
pub fn create_inbox(self, signer_identity: Identifier, nonce: u64) -> Self
Create a new inbox. This method must be called before any other methods or the IdentityUpdate will fail
Sourcepub fn add_association(
self,
new_member_identifier: MemberIdentifier,
existing_member_identifier: MemberIdentifier,
) -> Self
pub fn add_association( self, new_member_identifier: MemberIdentifier, existing_member_identifier: MemberIdentifier, ) -> Self
Add an AddAssociation action.
pub fn revoke_association( self, recovery_address_signer: MemberIdentifier, revoked_member: MemberIdentifier, ) -> Self
pub fn change_recovery_address( self, recovery_address_signer: MemberIdentifier, new_recovery_identifier: Identifier, ) -> Self
pub fn build(self) -> SignatureRequest