Identifier

Enum Identifier 

pub enum Identifier {
    Ethereum(Ethereum),
    Passkey(Passkey),
}
MemberIdentifier without the installation variant is used to enforce parameters. Not everything in this enum will be able to sign, which will be enforced on the unverified signature counterparts.

Variants



Ethereum(Ethereum)



Passkey(Passkey)

Implementations

Source

impl Identifier

pub fn sanitize(self) -> Result<Self, IdentifierValidationError>

pub fn eth(addr: impl ToString) -> Result<Self, IdentifierValidationError>

pub fn passkey(key: Vec<u8>, relying_party: Option<String>) -> Self

pub fn passkey_str( key: &str, relying_party: Option<String>, ) -> Result<Self, IdentifierValidationError>

pub fn from_proto( ident: impl AsRef<str>, kind: IdentifierKind, relying_party: Option<String>, ) -> Result<Self, ConversionError>

pub fn inbox_id(&self, nonce: u64) -> Result<String, AssociationError>

Get the generated inbox_id for this public identifier. The same public identifier will always give the same inbox_id.