pub enum MemberIdentifier {
Installation(Installation),
Ethereum(Ethereum),
Passkey(Passkey),
}Expand description
All identity logic happens here
Variants
Implementations
Sourceimpl MemberIdentifier
impl MemberIdentifier
pub fn sanitize(self) -> Result<Self, IdentifierValidationError>
pub fn eth(addr: impl ToString) -> Result<Self, IdentifierValidationError>
pub fn installation(key: Vec<u8>) -> Self
Sourcepub fn installation_key(&self) -> Option<&[u8]>
pub fn installation_key(&self) -> Option<&[u8]>
Get the value for MemberIdentifier::Installation variant.
Returns None if the type is not the correct variant.
Sourcepub fn eth_address(&self) -> Option<&str>
pub fn eth_address(&self) -> Option<&str>
Get the value for MemberIdentifier::Ethereum variant.
Returns None if the type is not the correct variant.
Sourcepub fn to_eth_address(self) -> Option<String>
pub fn to_eth_address(self) -> Option<String>
Get the value for MemberIdentifier::Ethereum, consuming the MemberIdentifier
in the process
Sourcepub fn to_installation(&self) -> Option<&[u8]>
pub fn to_installation(&self) -> Option<&[u8]>
Get the value for MemberIdentifier::Installation variant.
Returns None if the type is not the correct variant.