pub struct IdentityUpdate {
pub inbox_id: String,
pub client_timestamp_ns: u64,
pub actions: Vec<Action>,
}Expand description
An IdentityUpdate contains one or more Actions that can be applied to the AssociationState
Fields
inbox_id: Stringclient_timestamp_ns: u64actions: Vec<Action>Implementations
Sourceimpl IdentityUpdate
impl IdentityUpdate
pub fn new( actions: Vec<Action>, inbox_id: String, client_timestamp_ns: u64, ) -> Self
Sourcepub fn creation_signature_kind(&self) -> Option<SignatureKind>
pub fn creation_signature_kind(&self) -> Option<SignatureKind>
Get the signature kind used to create this inbox if this update contains a CreateInbox action. Returns None if there is no CreateInbox action in this update.
This is useful for determining whether an identity was created with a Smart Contract Wallet (Erc1271) or an Externally Owned Account/EOA (Erc191) signature