pub struct VerifiedSignature {
pub signer: MemberIdentifier,
pub kind: SignatureKind,
pub raw_bytes: Vec<u8>,
pub chain_id: Option<u64>,
}Fields
signer: MemberIdentifierkind: SignatureKindraw_bytes: Vec<u8>chain_id: Option<u64>Implementations
Sourceimpl VerifiedSignature
impl VerifiedSignature
pub fn new( signer: MemberIdentifier, kind: SignatureKind, raw_bytes: Vec<u8>, chain_id: Option<u64>, ) -> Self
Sourcepub fn from_recoverable_ecdsa<Text: AsRef<str>>(
signature_text: Text,
signature_bytes: &[u8],
) -> Result<Self, SignatureError>
pub fn from_recoverable_ecdsa<Text: AsRef<str>>( signature_text: Text, signature_bytes: &[u8], ) -> Result<Self, SignatureError>
Verifies an ECDSA signature against the provided signature text. Returns a VerifiedSignature if the signature is valid, otherwise returns an error.
Sourcepub fn from_recoverable_ecdsa_with_expected_address<Text: AsRef<str>>(
signature_text: Text,
signature_bytes: &[u8],
expected_address: Text,
) -> Result<Self, SignatureError>
pub fn from_recoverable_ecdsa_with_expected_address<Text: AsRef<str>>( signature_text: Text, signature_bytes: &[u8], expected_address: Text, ) -> Result<Self, SignatureError>
Verifies an ECDSA signature against the provided signature text and ensures that the recovered address matches the expected address.
Sourcepub fn from_installation_key<Text: AsRef<str>>(
signature_text: Text,
signature_bytes: &[u8],
verifying_key: VerifyingKey,
) -> Result<Self, SignatureError>
pub fn from_installation_key<Text: AsRef<str>>( signature_text: Text, signature_bytes: &[u8], verifying_key: VerifyingKey, ) -> Result<Self, SignatureError>
Verifies an installation key signature against the provided signature text and verifying key bytes. Returns a VerifiedSignature if the signature is valid, otherwise returns an error.
pub fn from_passkey<Text: AsRef<str>>( signature_text: Text, public_key: &[u8], signature: &[u8], authenticator_data: &[u8], client_data_json: &[u8], ) -> Result<Self, SignatureError>
Sourcepub fn from_legacy_delegated<Text: AsRef<str>>(
signature_text: Text,
signature_bytes: &[u8],
signed_public_key_proto: LegacySignedPublicKeyProto,
) -> Result<Self, SignatureError>
pub fn from_legacy_delegated<Text: AsRef<str>>( signature_text: Text, signature_bytes: &[u8], signed_public_key_proto: LegacySignedPublicKeyProto, ) -> Result<Self, SignatureError>
Verifies a legacy delegated signature and recovers the wallet address responsible associated with the signer.
Sourcepub async fn from_smart_contract_wallet<Text: AsRef<str>>(
signature_text: Text,
signature_verifier: impl SmartContractSignatureVerifier,
signature_bytes: &[u8],
account_id: AccountId,
block_number: &mut Option<u64>,
) -> Result<Self, SignatureError>
pub async fn from_smart_contract_wallet<Text: AsRef<str>>( signature_text: Text, signature_verifier: impl SmartContractSignatureVerifier, signature_bytes: &[u8], account_id: AccountId, block_number: &mut Option<u64>, ) -> Result<Self, SignatureError>
Verifies a smart contract wallet signature using the provided signature verifier.