pub enum Identifier {
Ethereum(Ethereum),
Passkey(Passkey),
}Expand description
MemberIdentifier without the installation variant is used to enforce parameters. Not everything in this enum will be able to sign, which will be enforced on the unverified signature counterparts.
Variants
Implementations
Sourceimpl Identifier
impl Identifier
pub fn sanitize(self) -> Result<Self, IdentifierValidationError>
pub fn eth(addr: impl ToString) -> Result<Self, IdentifierValidationError>
pub fn passkey(key: Vec<u8>, relying_party: Option<String>) -> Self
pub fn passkey_str( key: &str, relying_party: Option<String>, ) -> Result<Self, IdentifierValidationError>
pub fn from_proto( ident: impl AsRef<str>, kind: IdentifierKind, relying_party: Option<String>, ) -> Result<Self, ConversionError>